cmd_/opt/anaconda1anaconda2anaconda3/x86_64-conda_cos6-linux-gnu/sysroot/usr/include/linux/sunrpc/.install := perl /opt/conda/conda-bld/compilers_linux-64_1505664199673/work/.build/src/linux-2.6.32/scripts/headers_install.pl /opt/conda/conda-bld/compilers_linux-64_1505664199673/work/.build/src/linux-2.6.32/include/linux/sunrpc /opt/anaconda1anaconda2anaconda3/x86_64-conda_cos6-linux-gnu/sysroot/usr/include/linux/sunrpc x86 debug.h; perl /opt/conda/conda-bld/compilers_linux-64_1505664199673/work/.build/src/linux-2.6.32/scripts/headers_install.pl /opt/conda/conda-bld/compilers_linux-64_1505664199673/work/.build/x86_64-conda_cos6-linux-gnu/build/build-kernel-headers/include/linux/sunrpc /opt/anaconda1anaconda2anaconda3/x86_64-conda_cos6-linux-gnu/sysroot/usr/include/linux/sunrpc x86 ; touch /opt/anaconda1anaconda2anaconda3/x86_64-conda_cos6-linux-gnu/sysroot/usr/include/linux/sunrpc/.install
